pub struct Op { /* private fields */ }Expand description
Holds a set of bit flags representing the actions for the event.
For a list of possible values, have a look at the notify::op documentation.
Multiple actions may be delivered in a single event.
Implementations
Sourceimpl Op
impl Op
Sourcepub const CLOSE_WRITE: Op
pub const CLOSE_WRITE: Op
File opened for writing was closed
Sourcepub fn from_bits(bits: u32) -> Option<Op>
pub fn from_bits(bits: u32) -> Option<Op>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> Op
pub const fn from_bits_truncate(bits: u32) -> Op
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const fn intersects(&self, other: Op) -> bool
pub const fn intersects(&self, other: Op) -> bool
Returns true if there are flags common to both self and other.